The MPL Reference Manual: Trivial

Front Page / Metafunctions / Trivial

# Trivial

The MPL provides a number of Trivial Metafunctions that a nothing more than thin wrappers for a differently-named class nested type members. While important in the context of in-place metafunction composition, these metafunctions have so little to them that presenting them in the same format as the rest of the compoments in this manual would result in more boilerplate syntactic baggage than the actual content. To avoid this problem, we instead factor out the common metafunctions' requirements into the corresponding concept and gather all of them in a single place — this subsection — in a compact table form that is presented below.